/* param editor compact input fields */
.param-input .q-field__control {
  min-height: 32px !important;
  height: 32px !important;
}

.param-input .q-field__marginal {
  height: 32px !important;
}

.param-input .q-field__native {
  padding: 4px 12px !important;
  font-size: 13px;
  font-weight: 600;
}

.param-input input {
  font-size: 13px !important;
}

/* param editor zero-out Quasar expansion spacing */
.param-expansion .q-expansion-item__container,
.param-expansion .q-expansion-item__content,
.param-expansion .q-card,
.param-expansion .q-card__section,
.param-expansion .q-list,
.param-expansion .q-item__section {
  padding: 0 !important;
  margin: 0 !important;
}

.param-expansion .q-item {
  min-height: 32px !important;
  padding: 0 8px 0 12px !important;
  margin: 0 !important;
}

.param-expansion .q-item__section--side {
  padding: 0 !important;
  min-width: 20px !important;
}

.param-expansion .q-focus-helper {
  display: none !important;
}

.param-expansion .nicegui-column,
.param-expansion .nicegui-grid {
  gap: 6px !important;
  margin: 0 !important;
  padding-top: 0 !important;
  padding-bottom: 0 !important;
}

.param-card {
  border-radius: 6px;
  padding-top: 7px !important;
  padding-bottom: 7px !important;
  min-height: 58px;
}

.param-grid {
  width: 100%;
  min-width: 0;
  align-content: start;
}

.param-row {
  min-width: 0;
}

.param-meta {
  width: 34%;
  min-width: 0;
  max-width: 210px;
  overflow: hidden;
}

.param-label,
.param-meta .nicegui-label,
.param-meta label,
.param-meta span {
  overflow: hidden !important;
  text-overflow: ellipsis !important;
  white-space: nowrap !important;
}

.param-value-wrap {
  min-width: 0;
}

.param-value-wrap .q-field,
.param-value-wrap .nicegui-input {
  width: 100%;
}

.param-type-chip,
.param-section {
  border-radius: 5px;
}

@media (max-width: 1100px) {
  .param-row {
    flex-wrap: wrap !important;
    align-items: flex-start !important;
  }

  .param-meta {
    width: 100%;
    max-width: none;
  }

  .param-value-wrap {
    width: 100%;
  }
}
