/* monitor terminal-like log viewer */
.monitor-log-pre {
  font-family: "Cascadia Code", "Fira Code", "Consolas", "Monaco", monospace;
  font-size: 12px;
  line-height: 1.6;
  color: #d4d4d4;
  white-space: pre-wrap;
  word-break: break-all;
  padding: 8px 12px;
  margin: 0;
}

.monitor-xterm .xterm-viewport {
  padding-right: var(--monitor-xterm-gutter, 24px) !important;
  margin-right: 0 !important;
  box-sizing: content-box !important;
}

.monitor-sidebar {
  border-radius: var(--pr-radius-lg);
  box-shadow: var(--pr-shadow-sm);
}

.monitor-task-item {
  cursor: pointer;
  transition: background-color 0.08s ease;
  border-left: 3px solid transparent;
  flex-wrap: nowrap !important;
  overflow: hidden;
  border-radius: 6px;
  contain: layout style;
}

.monitor-task-item:hover {
  background: #eef5ff;
}

.monitor-task-item.active {
  background: #eef2ff;
  border-left-color: #6366f1;
}

.monitor-task-item .nicegui-label,
.monitor-task-item label,
.monitor-task-item span {
  white-space: nowrap !important;
  overflow: hidden !important;
  text-overflow: ellipsis !important;
}

.monitor-task-list-scroll {
  contain: layout;
}

.monitor-sidebar .q-field__control {
  border-radius: 6px !important;
}

.monitor-sidebar ::-webkit-scrollbar,
.manager-body ::-webkit-scrollbar,
.generator-form-scroll ::-webkit-scrollbar {
  width: 10px;
  height: 10px;
}

.monitor-sidebar ::-webkit-scrollbar-thumb,
.manager-body ::-webkit-scrollbar-thumb,
.generator-form-scroll ::-webkit-scrollbar-thumb {
  background: rgba(148, 163, 184, 0.55);
  border: 2px solid transparent;
  border-radius: 4px;
  background-clip: content-box;
}

@media (max-width: 1180px) {
  .monitor-sidebar {
    min-width: 220px !important;
  }
}
